# pymds

Metric multidimensional scaling in python.

## Install

It can be installed from command-line using
[pip](https://pypi.python.org/pypi/pip):

```bash
pip install pymds
```

## Documentation

Check out [pymds.readthedocs.io](https://pymds.readthedocs.io).

## License

This project is licensed under the MIT license.
